# This file is automatically generated. Please do not modify.

from . import AsciiArt

lede = AsciiArt(match=r'''"LEDE"*''', color='4 7 1', ascii=r"""
${c1}     _________
    /        /\
   /  LE    /  \
  /    DE  /    \
 /________/  LE  \
 \        \   DE /
  \    LE  \    /
   \  DE    \  /
    \________\/
""")
    