# This file is automatically generated. Please do not modify.

from . import AsciiArt

kslinux = AsciiArt(match=r'''"KSLinux"*''', color='4 7 1', ascii=r"""
${c1} K   K U   U RRRR   ooo
 K  K  U   U R   R o   o
 KKK   U   U RRRR  o   o
 K  K  U   U R  R  o   o
 K   K  UUU  R   R  ooo

${c2}  SSS   AAA  W   W  AAA
 S     A   A W   W A   A
  SSS  AAAAA W W W AAAAA
     S A   A WW WW A   A
  SSS  A   A W   W A   A
""")
    