# This file is automatically generated. Please do not modify.

from . import AsciiArt

t2 = AsciiArt(match=r'''"t2"*''', color='7 4', ascii=r"""
${c2}
TTTTTTTTTT
    tt   ${c1}222${c2}
    tt  ${c1}2   2${c2}
    tt     ${c1}2${c2}
    tt    ${c1}2${c2}
    tt  ${c1}22222${c2}
""")
    