# This file is automatically generated. Please do not modify.

from . import AsciiArt

astos = AsciiArt(match=r'''"astOS"*''', color='8', ascii=r"""
${c1}                oQA#$%UMn
                H       9
                G       #
                6       %
                ?#M#%KW3"
                  // \\
                //     \\
              //         \\
            //             \\
        n%@$DK&ML       .0O3#@&M_
        P       #       8       W
        H       U       G       #
        B       N       O       @
        C&&#%HNAR       'WS3QMHB"
          // \\              \\
        //     \\              \\
      //         \\              \\
    //             \\              \\
uURF$##Bv       nKWB$%ABc       aM@3R@D@b
8       M       @       O       #       %
%       &       G       U       @       @
&       @       #       %       %       #
!HGN@MNCf       t&$9#%HQr       ?@G#6S@QP
""")
    