# This file is automatically generated. Please do not modify.

from . import AsciiArt

semc = AsciiArt(match=r'''"semc"*''', color='2 8 1', ascii=r"""
${c1}            /\
     ______/  \
    /      |()| ${c2}E M C
${c1}   |   (-- |  |
    \   \  |  |
.----)   | |__|
|_______/ / ${c3}"${c1}  \
              ${c3}"
            "
""")
    