# This file is automatically generated. Please do not modify.

from . import AsciiArt

iglunix = AsciiArt(match=r'''"iglunix"*|"iglu"*''', color='8', ascii=r"""
${c1}     |
     |        |
              |
|    ________
|  /\   |    \
  /  \  |     \  |
 /    \        \ |
/      \________\
\      /        /
 \    /        /
  \  /        /
   \/________/
""")
    