# This file is automatically generated. Please do not modify.

from . import AsciiArt

pengwin = AsciiArt(match=r'''"Pengwin"*''', color='5 5 13', ascii=r"""
${c3}                     ...`
${c3}                     `-///:-`
${c3}                       .+${c2}ssys${c3}/
${c3}                        +${c2}yyyyy${c3}o    ${c2}
${c2}                        -yyyyyy:
${c2}           `.:/+ooo+/:` -yyyyyy+
${c2}         `:oyyyyyys+:-.`syyyyyy:
${c2}        .syyyyyyo-`   .oyyyyyyo
${c2}       `syyyyyy   `-+yyyyyyy/`
${c2}       /yyyyyy+ -/osyyyyyyo/.
${c2}       +yyyyyy-  `.-:::-.`
${c2}       .yyyyyy-
${c3}        :${c2}yyyyy${c3}o
${c3}         .+${c2}ooo${c3}+
${c3}           `.::/:.
""")
    