# This file is automatically generated. Please do not modify.

from . import AsciiArt

grapheneos = AsciiArt(match=r'''"GrapheneOS"*''', color='7 4', ascii=r"""
${c1}                        B?
                        G~
                        G~&
                      G!^:^?#
                     &^.:::.J
    &PG&          #G5JJ7~^~?JY5B&          #PG
     B5JJPGJ77YG5JYP#   &&   &B5JYPGJ7?YG5JYP#
        &Y..::.:P&               &?..::.:G
         #!::::?                  B~::::J
           B~J#                     B!?#
            !P                       75
            !P                       75
            !5                       7Y
         &Y~:^!P                  &J~:^!P
         P..::.:B                 Y..::.:#
      #PYJJ~^^!JJYP#          &B5YJ?~^^!JJYG#
    &YYG#   &&   #PYJ5G5??JGGYJ5G&   &&   #PYP
                     B^.::..7&
                      J::::^G
                       #Y^G&
                        B~
                        G!
                        #
""")
    