# This file is automatically generated. Please do not modify.

from . import AsciiArt

aster = AsciiArt(match=r'''"Aster"*''', color='6 6', ascii=r"""
${c1}                      ...''...
${c1}                 .;oOXWMWNXXXNMMN0d:.
${c1}              .oXMWOo;..       ..:oO;
${c1}            ;KMWx,       co,
${c1}          'KMNl         dMMW.
${c1}         oMMx          xMMMMk
${c1}        xMM:          dMMMMMM;
${c1}       cMMl          dMMMMMMMW
${c1}       NMK          xMMMx::dXMx
${c1}      ,MMl         xMMN'     .o.
${c1}      cMM;        dMMW'
${c1}      ;MMc       oMMW,
${c1}       WMK      dMMW,  ccccccc.
${c1}       lMMl    oMMM;   ooooooo.
${c1}        OMMc   ...
${c1}         xMMx
${c1}          ;XMN:
${c1}            ,.
""")
    