# This file is automatically generated. Please do not modify.

from . import AsciiArt

kali_small = AsciiArt(match=r'''"kali_small" | "kalilinux_small" | "kali_linux_small"''', color='4 8', ascii=r"""
${c1}     -#. #
      @###
  -######
 @#########
=##.  .#####
##      ## ##
##       ## #
##       @###
##.        ###
 ##%       ##-
  -##%    -*
   :*##+
     :*#*
       -#
        @
        :
""")
    