# This file is automatically generated. Please do not modify.

from . import AsciiArt

guix_small = AsciiArt(match=r'''"guix_small"*''', color='3 7 6 1 8', ascii=r"""
${c1}|.__          __.|
|__ \        / __|
   \ \      / /
    \ \    / /
     \ \  / /
      \ \/ /
       \__/
""")
    