# This file is automatically generated. Please do not modify.

from . import AsciiArt

hamonikr = AsciiArt(match=r'''"HamoniKR"*''', color='4 7 99 1 3 7', ascii=r"""
${c1}
                     cO0Ox.
                  .ldddddddo.
                .lddddddddddo
              'lddddddddddddc
            ,oddddddddddddd;
          'ldddddddddddddo.
        .oddddddddddddddc.
      ,dddddddddddddddo.
    ,ccoooooooocoddooo:
  ,cooooooooooooooooop ${c3}                 c000x.
${c1}.cooooooooooooooopcllll${c3}              .cddddddo.
${c1}coooooooooooooop' .qlll.${c3}           .ddoooooooo;
${c1}cooooooooooc;        ${c3}'qlllp.     .ddoooooooooo;
${c1}.cooooooc;             ${c3}'lllbc...coooooooooooo;
${c1}  .cooc'                ${c3}.llllcoooooooooooooo.
                         .coooooooooooooop:
                       .coooooooooooooop'
                      .cooooooooooooop.
                    .cooooooooooooop.
                   .coooooooooooop.
                  .cooooooooooop.
                  .cooooooooop.
                   .cooooop'
""")
    