# This file is automatically generated. Please do not modify.

from . import AsciiArt

parch = AsciiArt(match=r'''"parch"* | "Parch"* | "PARCH"*''', color='4 7 1', ascii=r"""
${c1}                       ,:lodddd.
                   .:clooood.
                 ;clllooooc
               ;cclllllloo
              .cccccllllll
            .   ,cccclllll
           ':::;; ccccclll;
          .:::cccccccccccll;
          ;::::ccccllllllcll:
         .;::::cccclllloool::;
         ;;;::::cccclllolc::::;.
         ;;;::::cccclllccc:::::;.
         ;;;::::cccclccccc::::::;.
         ;;;;::::::llcccccc:::::'
         ;;;;:; ,clllccccccc::
         .;;  .cllllllcccccc::;::::'
             .'''''''''',:lddoooolll
            '.....'''',cdddooooollll
           ........':oddddoooolllllc
            ....';ldddddooooolllllc:
              ,cdddddddooooollllccc
               :ddddddoooolllllccc
                 ;ddooooolllllcc.
                    :ooollllc.
                        c'
""")
    