# This file is automatically generated. Please do not modify.

from . import AsciiArt

dragonfly_small = AsciiArt(match=r'''"dragonfly_small"*''', color='1 7 3', ascii=r"""
${c2}   ,${c1}_${c2},
('-_${c1}|${c2}_-')
 >--${c1}|${c2}--<
(_-'${c1}|${c2}'-_)
    ${c1}|
    |
    |
""")
    