# This file is automatically generated. Please do not modify.

from . import AsciiArt

pearos = AsciiArt(match=r'''"pearOS"*''', color='2 3 1 1 5 4', ascii=r"""
\e[0;32m                  .+yh
                 sMMMo
                sMMN+
                +o:    \e[0m
\e[93m           ./oyyys+.
         :dMMMMMMMMMm/
        :MMMMMMMMMMMMMy
        yMMMMMMMMMMMMMN \e[0m
\e[31m        mMMMMMMMMMMMMs`
       yMMMMMMMMMMMMo
     -mMMMMMMMMMMMMM`
    oMMMMMMMMMMMMMMM` \e[0m
\e[95m   oMMMMMMMMMMMMMMMMy
  .MMMMMMMMMMMMMMMMMMy`
  +MMMMMMMMMMMMMMMMMMMMy/`
  /MMMMMMMMMMMMMMMMMMMMMMMNds \e[0m
\e[34m  `mMMMMMMMMMMMMMMMMMMMMMMMM/
   .mMMMMMMMMMMMMMMMMMMMMMM+
    `oNMMMMMMMMMMMMMMMMMMd-
      `+hMMMMMMMMMMMMMms-
          -/osyhhyso:. \e[0m
""")
    