# This file is automatically generated. Please do not modify.

from . import AsciiArt

aeros = AsciiArt(match=r'''"aerOS"*''', color='fg 0 0 0', ascii=r"""
${c1}
                   ooo OOO OOO ooo
               oOO                 OOo
           oOO                         OOo
        oOO                               OOo
      oOO                                   OOo
    oOO                                       OOo
   oOO                                         OOo
                                                OOo
                                                 OOo
                                                 OOo
                                                 OOo
                                                 OOo
                                                 OOo
  oOO                                           OOo
   oOO                                         OOo
    oOO                                       OOo
      oOO                                   OOo
        oO                                OOo
           oOO                         OOo
               oOO                 OOo
                   ooo OOO OOO ooo
""")
    