# This file is automatically generated. Please do not modify.

from . import AsciiArt

opensuse_tumbleweed = AsciiArt(match=r'''"openSUSE Tumbleweed"* | "openSUSE_Tumbleweed"*''', color='2 7', ascii=r"""
${c2}                                     ......
     .,cdxxxoc,.               .:kKMMMNWMMMNk:.
    cKMMN0OOOKWMMXo. A        ;0MWk:'      ':OMMk.
  ;WMK;'       'lKMMNM,     :NMK'             'OMW;
 cMW;             WMMMN   ,XMK'                 oMM.
.MMc             ''^*~l. xMN:                    KM0
'MM.                   .NMO                      oMM
.MM,                 .kMMl                       xMN
 KM0               .kMM0' .dl>~,.               .WMd
 'XM0.           ,OMMK'    OMMM7'              .XMK
   *WMO:.    .;xNMMk'       NNNMKl.          .xWMx
     ^ONMMNXMMMKx;          V  'xNMWKkxllox0NMWk'
         '''''                    ':dOOXXKOxl'
""")
    