# This file is automatically generated. Please do not modify.

from . import AsciiArt

pureos_small = AsciiArt(match=r'''"pureos_small"*''', color='2 7 7', ascii=r"""
${c1} _____________
|  _________  |
| |         | |
| |         | |
| |_________| |
|_____________|
""")
    