# This file is automatically generated. Please do not modify.

from . import AsciiArt

freebsd_small = AsciiArt(match=r'''"freebsd_small"''', color='1 7 3', ascii=r"""
${c1}/\,-'''''-,/\
\_)       (_/
|           |
|           |
 ;         ;
  '-_____-'
""")
    