# This file is automatically generated. Please do not modify.

from . import AsciiArt

stock_linux = AsciiArt(match=r'''"Stock Linux"*''', color='4 7', ascii=r"""
${c1}

              #G5J5G#
          &BPYJJJJJJJYPB&
      &#G5JJJJJJY5YJJJJJJ5G#&
   #G5YJJJJJY5G#& &#G5YJJJJJY5G#
BPYJJJJJJJ5B&         &BPYJJJJJJYPB
JJJJJJJJJJY5G#&           &BPYJJJJJ
JJJJJJJJJJJJJJY5G#           &JJJJJ
PYJJJJJJJJJJJJJJJJYPB&        GYJJJ
  &BPYJJJJJJJJJJJJJJJJ5PB&      &BP
      #G5YJJJJJJJJJJJJJJJY5G#
PB&      &BP5JJJJJJJJJJJJJJJJYPB&
JJJYG        &BPYJJJJJJJJJJJJJJJJYP
JJJJJ&           #G5YJJJJJJJJJJJJJJ
JJJJJYPB&           &#G5YJJJJJJJJJJ
BPYJJJJJJYPB&         &B5JJJJJJJYPB
   #G5YJJJJJY5G#& &#G5YJJJJJY5G#
      &#G5JJJJJJY5YJJJJJJ5G#&
          &BPYJJJJJJJYPB&
              #G5J5G#
""")
    