# This file is automatically generated. Please do not modify.

from . import AsciiArt

parabola_small = AsciiArt(match=r'''"parabola_small"*''', color='5 7', ascii=r"""
${c1}  __ __ __  _
.`_//_//_/ / `.
          /  .`
         / .`
        /.`
       /`
""")
    