# This file is automatically generated. Please do not modify.

from . import AsciiArt

massos = AsciiArt(match=r'''"MassOS"*''', color='7', ascii=r"""
${c1} -+++/+++osyyhdmNNMMMMNdy/
 /MMMMMMMMMMMMMMMMMMMMMMMMm.
 /MMMMMMMMMMMMMMMMMMMMMMMMMm
 /MMMMMMMMMMMMMMMMMMMMMMMMMM:
 :ddddddddhddddddddhdddddddd/
 /NNNNNNNm:NNNNNNNN-NNNNNNNNo
 /MMMMMMMN:MMMMMMMM-MMMMMMMMs
 /MMMMMMMN:MMMMMMMM-MMMMMMMMs
 /MMMMMMMN:MMMMMMMM-MMMMMMMMs
 /MMMMMMMN:MMMMMMMM-MMMMMMMMs
 /MMMMMMMN:MMMMMMMM-MMMMMMMMs
 /MMMMMMMN:MMMMMMMM-MMMMMMMMs
 /MMMMMMMN:MMMMMMMM-MMMMMMMMs
 /MMMMMMMN:MMMMMMMM-MMMMMMMMs
 :MMMMMMMN:MMMMMMMM-MMMMMMMMs
  dMMMMMMN:MMMMMMMM-MMMMMMMMs
  `yNMMMMN:MMMMMMMM-MMMMMMMMs
    `:+oss.ssssssss.ssssssss/
""")
    