# This file is automatically generated. Please do not modify.

from . import AsciiArt

venom = AsciiArt(match=r'''"Venom"*''', color='8 4', ascii=r"""
${c1}
   `-`
    -yys+/-`
     `oyyyyy: /osyyyyso+:.
       /yyyyy+`+yyyyyyyyyys/.
       .-yyyyys.:+//+oyyyyyyyo.
     `oy/`oyyyyy/      ./syyyyy:
     syyys`:yyyyyo`       :yyyyy:
    /yyyyo  .syyyyy-       .yyyyy.
    yyyyy.    +yyyyy/       /yyyy/
   `yyyyy      :yyyyys`     -yyyyo
    yyyyy.      `syyyyy-    /yyyy/
    /yyyyo        /yyyyy+  .yyyyy.
     syyyys.       -yyyyys.:yyyy:
     `oyyyyyo-`     `oyyyyy:.sy:
       :syyyyyyso+/++`/yyyyyo``
         -oyyyyyyyyyyy-.syyyys.
            -/+osyyyyso.`+yyyyy/
                          .-/+syo`
                                `.
""")
    