# This file is automatically generated. Please do not modify.

from . import AsciiArt

mainsailos_small = AsciiArt(match=r'''"MainsailOS_small"*''', color='1', ascii=r"""
${c1}          -:
         +%*
       .#%%+
      -%%%: +=
     +%%#..#%%-
   .#%%+ -%%%- +=
  -%%%- +%%#..#%%+
""")
    