# This file is automatically generated. Please do not modify.

from . import AsciiArt

popos_small = AsciiArt(match=r'''"popos_small"* | "pop_os_small"*''', color='6 7', ascii=r"""
${c1}______
\   _ \        __
 \ \ \ \      / /
  \ \_\ \    / /
   \  ___\  /_/
    \ \    _
   __\_\__(_)_
  (___________)`
""")
    