# This file is automatically generated. Please do not modify.

from . import AsciiArt

ubuntu_kylin = AsciiArt(match=r'''"Ubuntu Kylin"* | "Ubuntu-Kylin"*''', color='1 7 3', ascii=r"""
${c1}            .__=liiiiiii=__,
        ._=liiliii|i|i|iiilii=_.
      _=iiiii|ii|i|ii|i|inwwwzii=,
    .=liiii|ii|ii|wwww|i${c2}3QWWWW${c1}ziii=,
   =lii|i|ii|i|${c2}QQQWWWWWm]QWWQD${c1}||iiii=
  =lii|iiivw${c2}Qm${c1}>3${c2}WWWWWQWQQwwQw${c1}cii|i|ii=
 =lii|ii|n${c2}QWWWQ${c1}|)i${c2}|i${c1}%i|]${c2}TQWWWWm${c1}|ii|i|i=
.li|i|i|m${c2}WWWQV${c1}|ii${c2}wmD${c1}|iiii|${c2}TWWWWm${c1}|i|iiii,
=iii${c2}www|$WQWk${c1}|i${c2}aWWWD${c1}|i|i|ii]${c2}QQWQk${c1}|ii|i|=
iii${c2}QWWWQz$WW${c1}|i${c2}jQQWQm${c1}w|ii${c2}wW${c1}k|${c2}TTTTY${c1}i|i|iii
iiI${c2}QWQWWtyQQ${c1}|i|${c2}$WWWWWQWk${c1}||i|i|ii||i|ii|i
<|i|${c2}TTT|mQQWz${c1}|i${c2}3D${c1}]C|${c2}nD$W${c1}|ii${c2}vWWWWk${c1}||ii|i>
-|ii|i|i${c2}WWWQw${c1}|${c2}Tt${c1}|i3${c2}T${c1}|${c2}T${c1}|i|${c2}nQWQWDk${c1}|ii|ii`
 <|i|iii|${c2}VWQWWQ${c1}|i|i|||ii${c2}wmWWQWD${c1}||ii|ii+
  <|ii|i|i]${c2}$W@${c1}tv${c2}QQQWQQQWWTTHT${c1}1|iii|i|>
   <|i|ii|ii||v${c2}QWWWQWWW@vmWWWm${c1}|i|i|i>
    -<|i|ii|ii|i|${c2}TTTTTT${c1}|]${c2}QQWWWC${c1}|ii>`
      -<|i|ii|i|ii|i|i|ii3${c2}TTT${c1}t|i>`
         ~<|ii|ii|iiiii|i|||i>~
            -~~<|ii|i||i>~~`
""")
    