# This file is automatically generated. Please do not modify.

from . import AsciiArt

hyperbola_small = AsciiArt(match=r'''"hyperbola_small"*''', color='8', ascii=r"""
${c1}    |`__.`/
    \____/
    .--.
   /    \
  /  ___ \
 / .`   `.\
/.`      `.\
""")
    