# This file is automatically generated. Please do not modify.

from . import AsciiArt

linuxlite_small = AsciiArt(match=r'''"linuxlite_small"*''', color='3 7', ascii=r"""
${c1}   /\
  /  \
 / ${c2}/ ${c1}/
> ${c2}/ ${c1}/
\ ${c2}\ ${c1}\
 \_${c2}\${c1}_\
${c2}    \
""")
    