# This file is automatically generated. Please do not modify.

from . import AsciiArt

vzlinux = AsciiArt(match=r'''"VzLinux"*''', color='1 7 3', ascii=r"""
${c2}                 ${c1}.::::::::.${c2}
    `/////`      ${c1}:zzzzzzzz${c2}        ://///-
     VVVVVu`         ${c1}-zzz`${c2}       /VVVVV.
     `dVVVVV        ${c1}.zzz`${c2}       :VVVVV:
      `VVVVVo       ${c1}zzz${c2}        -VVVVV/
       .VVVVV\     ${c1}zzz/${c2}       .VVVVV+
        -VVVVV:   ${c1}zzzzzzzzz${c2}  .dVVVVs
         \VVVVV-  ${c1}`````````${c2}  VVVVVV
          +VVVVV.           sVVVVu`
           oVVVVd`         +VVVVd`
            VVVVVV        /VVVVV.
            `uVVVVs      -VVVVV-
             `dVVVV+    .VVVVV/
              .VVVVV\  `dVVVV+
               -VVVVV-`uVVVVo
                :VVVVVVVVVVV
                 \VVVVVVVVu
                  oVVVVVVd`
                   sVVVVV.
                    ----.
""")
    