# This file is automatically generated. Please do not modify.

from . import AsciiArt

android_small = AsciiArt(match=r'''"android_small"*''', color='2 7', ascii=r"""
${c1}  ;,           ,;
   ';,.-----.,;'
  ,'           ',
 /    O     O    \
|                 |
'-----------------'
""")
    