# This file is automatically generated. Please do not modify.

from . import AsciiArt

endeavouros_small = AsciiArt(match=r'''"endeavouros_small"*''', color='1 5 4', ascii=r"""
${c1}           /${c2}o${c3}.
${c1}         :${c2}sssso${c3}-
${c1}       :${c2}ossssssso${c3}:
${c1}     /${c2}ssssssssssso${c3}+
${c1}  -+${c2}ssssssssssssssso${c3}+
${c1} //${c2}osssssssssssssso${c3}+-
  `+++++++++++++++-`
""")
    