# This file is automatically generated. Please do not modify.

from . import AsciiArt

kaisen = AsciiArt(match=r'''"Kaisen"*''', color='1 7 3', ascii=r"""
${c1}                          `
                  `:+oyyho.
             `+:`sdddddd/
        `+` :ho oyo++ohds-`
       .ho :dd.  .: `sddddddhhyso+/-
       ody.ddd-:yd- +hysssyhddddddddho`
       yddddddhddd` ` `--`   -+hddddddh.
       hddy-+dddddy+ohh/..+sddddy/:::+ys
      :ddd/sdddddddddd- oddddddd       `
     `yddddddddddddddd/ /ddddddd/
:.  :ydddddddddddddddddo..sddddddy/`
odhdddddddo- `ddddh+-``....-+hdddddds.
-ddddddhd:   /dddo  -ydddddddhdddddddd-
 /hdy:o - `:sddds   .`./hdddddddddddddo
  `/-  `+hddyosy+       :dddddddy-.-od/
      :sydds           -hddddddd`    /
       .+shd-      `:ohddddddddd`
                `:+ooooooooooooo:
""")
    