# This file is automatically generated. Please do not modify.

from . import AsciiArt

langitketujuh = AsciiArt(match=r'''"LangitKetujuh"*''', color='4 2', ascii=r"""
${c1}
. 'MMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMML7
MM.   'MMMMMMMMMMMMMMMMMMMMMMMMMMML7L7
MMMMMM     MMMMMMML7L7L7L7L7L7L7L7L7L7
L7MMMM                          L7L7L7
L7L7MM           'L7L7L7L7L7L7L7L7L7L:
L7L7L7               'L7L7L7L7L7L7L:::
L7L7L7                   'L7L7L7::::::
:7L7L7                          ::::::
::L7L7L7L7L7L7L7L7L7L::::::.    ::::::
:::::7L7L7L7L7L7:::::::::::::::.   '::
:::::::::::::::::::::::::::::::::::. '
${c2}
""")
    