# This file is automatically generated. Please do not modify.

from . import AsciiArt

center = AsciiArt(match=r'''"Center"*''', color='7 7', ascii=r"""
${c2}                .
                o,
        .       d,       .
        ';'   ..d;..  .cl'
          .:; 'oldO,.oo.
          ..,:,xKXxoo;'.
    ,;;;;;ldxkONMMMXxkxc;;;;;.
    .....':oddXWMNOxlcl:......
           .:dlxk0c;:. .
          :d:.,xcld,.,:.
        ;l,    .l;     ';'
               .o;
                l,
""")
    