# This file is automatically generated. Please do not modify.

from . import AsciiArt

sunos_small = AsciiArt(match=r'''"sunos_small" | "solaris_small"''', color='3 7', ascii=r"""
${c1}       .   .;   .
   .   :;  ::  ;:   .
   .;. ..      .. .;.
..  ..             ..  ..
 .;,                 ,;.
""")
    