# This file is automatically generated. Please do not modify.

from . import AsciiArt

mageia_small = AsciiArt(match=r'''"mageia_small"*''', color='6 7', ascii=r"""
${c1}   *
    *
   **
${c2} /\__/\
/      \
\      /
 \____/
""")
    