# This file is automatically generated. Please do not modify.

from . import AsciiArt

aperio_gnu_linux = AsciiArt(match=r'''"Aperio GNU/Linux"*''', color='255', ascii=r"""
${c2}
 _.._  _ ._.. _
(_][_)(/,[  |(_)
   |   GNU/Linux
""")
    