# This file is automatically generated. Please do not modify.

from . import AsciiArt

ghostbsd = AsciiArt(match=r'''"GhostBSD"*''', color='4', ascii=r"""
${c1}           ,gggggg.
        ,agg9*   .g)
      .agg* ._.,gg*
    ,gga*  (ggg*'
   ,ga*       ,ga*
  ,ga'     .ag*
 ,ga'   .agga'
 9g' .agg'g*,a
 'gggg*',gga'
      .gg*'
    .gga*
  .gga*
 (ga*
""")
    