# This file is automatically generated. Please do not modify.

from . import AsciiArt

linuxmint_small = AsciiArt(match=r'''"linuxmint_small"*''', color='2 7', ascii=r"""
${c1} ___________
|_          \
  | ${c2}| _____ ${c1}|
  | ${c2}| | | | ${c1}|
  | ${c2}| | | | ${c1}|
  | ${c2}\__${c2}___/ ${c1}|
  \_________/
""")
    