# This file is automatically generated. Please do not modify.

from . import AsciiArt

debian_small = AsciiArt(match=r'''"debian_small"''', color='1 7 3', ascii=r"""
${c1}  _____
 /  __ \
|  /    |
|  \___-
-_
  --_
""")
    